@@ -32,7 +32,12 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  app = phosh_tour_application_new ("sm.puri.PhoshTour", G_APPLICATION_FLAGS_NONE);
+  app = phosh_tour_application_new ("sm.puri.PhoshTour",
+#if GLIB_CHECK_VERSION(2,74,0)
+                                         G_APPLICATION_DEFAULT_FLAGS);
+#else
+                                         G_APPLICATION_FLAGS_NONE);
+#endif
   ret = g_application_run (G_APPLICATION (app), argc, argv);
 
   return ret;
